package backend

import (
	"cron_admin/app/http/entities"
	"cron_admin/app/models/cronreportchannelmodel"
)

type ReportChannelListRequest struct {
	entities.PageRequest
	ReportChannelId int `json:"report_channel_id" form:"report_channel_id" validate:"min=0"`
	Status          int `json:"status" form:"status"`
}

type ReportChannelListResponse struct {
	ReportChannelId uint   `json:"report_channel_id"`
	ClientKey       string `json:"client_key"`
	ClientSecret    string `json:"client_secret"`
	Config          string `json:"config"`
	CreateTime      string `json:"create_time"`
	Status          int    `json:"status"`
}

func (this *ReportChannelListResponse) FromDb(in cronreportchannelmodel.CronReportChannel) {
	this.ReportChannelId = in.ReportChannelId
	this.ClientKey = in.ClientKey
	this.ClientSecret = in.ClientSecret
	this.Config = in.Config
	this.CreateTime = in.CreateTime.Format("2006-01-02 15:04:05")
	this.Status = in.Status
}

type ReportChannelCreateRequest struct {
	ClientKey    string `json:"client_key" validate:"required" label:"服务key"`
	ClientSecret string `json:"client_secret" validate:"required" label:"服务secret"`
	Config       string `json:"config" validate:"required" label:"服务配置"`
	Status       int    `json:"status" validate:"required" label:"状态"`
}

func (this *ReportChannelCreateRequest) Request2DB() (db cronreportchannelmodel.CronReportChannel) {
	db.ClientKey = this.ClientKey
	db.ClientSecret = this.ClientSecret
	db.Config = this.Config
	db.Status = this.Status
	return db
}

type ReportChannelUpdateRequest struct {
	ReportChannelId uint   `json:"report_channel_id"`
	ClientKey       string `json:"client_key" validate:"required" label:"配置key"`
	ClientSecret    string `json:"client_secret" validate:"required" label:"配置密钥"`
	Config          string `json:"config" validate:"required" label:"配置"`
	Status          int    `json:"status" validate:"required" label:"状态"`
}

func (this *ReportChannelUpdateRequest) Request2DB() (db cronreportchannelmodel.CronReportChannel) {
	db.ReportChannelId = this.ReportChannelId
	db.ClientKey = this.ClientKey
	db.ClientSecret = this.ClientSecret
	db.Config = this.Config
	db.Status = this.Status
	return db
}
